@@ -48,6 +48,24 @@
 
 using namespace Opal;
 
+static void
+strip_special_chars (std::string& str, char* special_chars, bool start)
+{
+  std::string::size_type idx;
+
+  unsigned i = 0;
+  while (i < strlen (special_chars)) {
+    idx = str.find_first_of (special_chars[i]);
+    if (idx != std::string::npos) {
+      if (start)
+        str = str.substr (idx+1);
+      else
+        str = str.substr (0, idx);
+    }
+    i++;
+  }
+}
+
 class CallSetup : public PThread
 {
   PCLASSINFO(CallSetup, PThread);
@@ -112,20 +130,10 @@ Opal::Call::hangup ()
 void
 Opal::Call::answer ()
 {
-  PSafePtr<OpalConnection> connection = NULL;
-  int i = 0;
-
   if (!is_outgoing () && !IsEstablished ()) {
-
-    do {
-
-      connection = GetConnection (i);
-      i++;
-    }  while (!PIsDescendant(&(*connection), OpalPCSSConnection));
-
-    if (PIsDescendant(&(*connection), OpalPCSSConnection)) {
-      PDownCast (OpalPCSSConnection, &(*connection))->AcceptIncoming ();
-    }
+    PSafePtr<OpalPCSSConnection> connection = GetConnectionAs<OpalPCSSConnection>();
+    if (connection != NULL)
+      connection->AcceptIncoming();
   }
 }
 
@@ -312,22 +320,24 @@ Opal::Call::is_outgoing () const
 void
 Opal::Call::parse_info (OpalConnection & connection)
 {
-  char special_chars [] = "([;=";
-  int i = 0;
-  std::string::size_type idx;
+  char start_special_chars [] = "$";
+  char end_special_chars [] = "([;=";
+
   std::string l_party_name;
   std::string r_party_name;
   std::string app;
 
-  remote_uri = (const char *) connection.GetRemotePartyCallbackURL ();
   if (!PIsDescendant(&connection, OpalPCSSConnection)) {
 
     outgoing = connection.IsOriginating ();
 
     remote_uri = (const char *) connection.GetRemotePartyCallbackURL ();
 
-    l_party_name = (const char *) connection.GetCalledPartyURL ();
-    r_party_name = (const char *) connection.GetRemotePartyName ();
+    l_party_name = (const char *) connection.GetLocalPartyName ();
+    if (connection.GetRemotePartyName () == connection.GetRemotePartyAddress ())
+      r_party_name = remote_uri;
+    else
+      r_party_name = (const char *) connection.GetRemotePartyName ();
     app = (const char *) connection.GetRemoteProductInfo ().AsString ();
     start_time = connection.GetConnectionStartTime ();
     if (!start_time.IsValid ())
@@ -340,21 +350,12 @@ Opal::Call::parse_info (OpalConnection & connection)
     if (!app.empty ())
       remote_application = app;
 
-    while (i < 3) {
+    strip_special_chars (remote_party_name, end_special_chars, false);
+    strip_special_chars (remote_application, end_special_chars, false);
+    strip_special_chars (remote_uri, end_special_chars, false);
 
-      idx = remote_party_name.find_first_of (special_chars [i]);
-      if (idx != std::string::npos)
-        remote_party_name = remote_party_name.substr (0, idx);
-
-      idx = remote_application.find_first_of (special_chars [i]);
-      if (idx != std::string::npos)
-        remote_application = remote_application.substr (0, idx);
-
-      idx = remote_uri.find_first_of (special_chars [i]);
-      if (idx != std::string::npos)
-        remote_uri = remote_uri.substr (0, idx);
-      i++;
-    }
+    strip_special_chars (remote_party_name, start_special_chars, true);
+    strip_special_chars (remote_uri, start_special_chars, true);
   }
 }
 
